@@ -106,10 +106,17 @@ def mono_repo_qa(project, branch_name):
 def twigify(projects_list):
     projects_dict = {}
     for project in projects_list:
+        committer = ""
+
+        try:
+            committer = project[1].commit.committer.email or ""
+        except Exception:
+            committer = project[1].commit.commit.committer.email or ""
+
         projects_dict[project[0]] = {
             "name": project[1].name,
             "revision": project[1].commit.sha[:15],
-            "committer": project[1].commit.committer.email or "",
+            "committer": committer,
             "default_branch": False,
         }
 
