@@ -6,7 +6,7 @@ import sys
 from halo import Halo
 
 from suite_py.lib.handler.github_handler import GithubHandler
-from suite_py.lib.handler.slack_handler import SlackHandler
+from suite_py.lib.handler.captainhook_handler import CaptainHook
 from suite_py.lib.handler import prompt_utils
 from suite_py.lib.handler import aws_handler as aws
 from suite_py.lib.handler import drone_handler as drone
@@ -15,10 +15,13 @@ from suite_py.lib.logger import Logger
 
 github = GithubHandler()
 logger = Logger()
-slack = SlackHandler()
+captainhook = CaptainHook()
 
 
-def entrypoint(project):
+def entrypoint(project, timeout):
+    if timeout:
+        captainhook.set_timeout(timeout)
+
     bucket_name = "prima-artifacts-encrypted"
     repo = github.get_repo(project)
 
@@ -46,7 +49,7 @@ def entrypoint(project):
         build = drone.get_build_from_tag(project, version)
         drone.launch_build(project, build)
         logger.info("Build rilanciata, controlla lo stato su drone")
-        post_rollback_complete_on_slack(project, version)
+        captainhook.rollback(project, version)
 
     else:
         stacks_name = aws.get_stacks_name(project)
@@ -113,12 +116,5 @@ def get_versions_from_artifacts(project, bucket_name, artifacts):
 
 def rollback_stacks(project, stacks_name, version):
     aws.update_stacks(stacks_name, version)
-    post_rollback_complete_on_slack(project, version)
+    captainhook.rollback(project, version)
     logger.info(f"Rollback completato con successo. Versione in produzione: {version}")
-
-
-def post_rollback_complete_on_slack(project, version):
-    slack.post(
-        "deploy_channel",
-        f"ho effettuato il rollback di {project}. Versione in produzione: {version}",
-    )
